shell

package
v0.25.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Overview

Package shell implements an interactive shell that displays the tootik UI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(
	ctx context.Context,
	domain string,
	u *url.URL,
	fetch func(context.Context, *url.URL) (*url.URL, string, error),
) error

Run runs an interactive shell.

It uses fetch to fetch the next page and follows redirects.

Types

This section is empty.

Jump to